@@ -48,12 +48,12 @@ class EventsManager extends CGExtensions
 			$name = $this->Lang('friendlyname');
 		return $name;
 	}
-	function GetVersion() { return '0.1.7'; }
+	function GetVersion() { return '0.1.8'; }
 	function GetHelp() { return $this->Lang('help'); }
 	function GetAuthor() { return 'AireLibre'; }
 	function GetAuthorEmail() { return 'contact@airelibre.fr'; }
 	function GetChangeLog() { return file_get_contents(__FILE__).'/doc/changelog.html'; }
-	function MinimumCMSVersion() {return '1.9';}
+	function MinimumCMSVersion() {return '1.10';}
 	function MaximumCMSVersion() {return '1.11';}
 	
 	function InstallPostMessage() { return $this->Lang('postinstall'); }
@@ -85,6 +85,9 @@ class EventsManager extends CGExtensions
 		/* Routes - URL Rewriting */
 		// Detail : /prefix/event_id/returnid/alias
 		$urlprefix = $this->GetPreference('urlprefix', '[Ee]vents');
+		if (empty($urlprefix))
+			$urlprefix = 'events';
+
 		// With detail template
 		$this->RegisterRoute('/' . $urlprefix . '\/(?P<event_id>[0-9]+)\/(?P<returnid>[0-9]+)\/(?P<junk>.*?)\/d,(?P<detailtemplate>.*?)$/', array('action'=>'detail'));
 		// Classic link
@@ -112,6 +115,8 @@ class EventsManager extends CGExtensions
 		$this->SetParameterType('start_datetime', CLEAN_STRING);
 		$this->SetParameterType('end_datetime', CLEAN_STRING);
 		$this->SetParameterType('myevents', CLEAN_STRING);
+		$this->SetParameterType('sortby', CLEAN_STRING);
+		$this->SetParameterType('sortorder', CLEAN_STRING);
 		
 		// Templates
 		$this->SetParameterType('summarytemplate', CLEAN_STRING);
@@ -131,6 +136,8 @@ class EventsManager extends CGExtensions
 		$this->CreateParameter('start_datetime', '', $this->Lang('param_start_datetime'));
 		$this->CreateParameter('end_datetime', '', $this->Lang('param_end_datetime'));
 		$this->CreateParameter('myevents', 'false', $this->Lang('param_myevents'));
+		$this->CreateParameter('sortby', 'name', $this->Lang('param_sortby'));
+		$this->CreateParameter('sortorder', 'ASC', $this->Lang('param_sortorder'));
 		
 		// Templates
 		$this->CreateParameter('summarytemplate', '', $this->Lang('param_summarytemplate'));
