@@ -62,8 +62,16 @@ $myevents = false;
 if (isset($params['myevents']) AND ($params['myevents']==1 OR $params['myevents'] == 'true'))
 	$myevents = true;
 	
+// Sortby and sortorder
+$sortby = 'name';
+$sortorder = 'ASC';
+if (isset($params['sortby']) and !empty($params['sortby']))
+	$sortby = $params['sortby'];
+if (isset($params['sortorder']) and !empty($params['sortorder']))
+	$sortorder = $params['sortorder'];
+	
 // Load the events
-$events = EventsManager_events_ops::get_events($status, $category_id, $category_name, $show, $start_datetime, $end_datetime, $myevents);
+$events = EventsManager_events_ops::get_events($status, $category_id, $category_name, $show, $start_datetime, $end_datetime, $myevents, $sortby, $sortorder);
 
 // Add links
 $events_smarty = array();
